# JWT Auth React

![npm](https://img.shields.io/npm/v/jwt-auth-react?logo=npm&style=flat-square)
![npm bundle size](https://img.shields.io/bundlephobia/minzip/jwt-auth-react?logo=npm&style=flat-square)
![npm](https://img.shields.io/npm/dw/jwt-auth-react?logo=npm&style=flat-square)
![GitHub top language](https://img.shields.io/github/languages/top/darkmatter18/jwt-auth-react?logo=typescript&style=flat-square)
![dependencies](https://img.shields.io/david/darkmatter18/jwt-auth-react?style=flat-square)
![GitHub License](https://img.shields.io/github/license/darkmatter18/jwt-auth-react?logo=apache&style=flat-square)

React [Context](https://reactjs.org/docs/context.html) and [Hooks](https://reactjs.org/docs/hooks-intro.html) based 
`Authentication` Package for [React](https://reactjs.org/) Apps

## Installation

Install the `jwt-auth-react` as a dependency in your React app.

```cmd
npm install jwt-auth-react
```

This will install the package and will create an entry in your App's `package.json` file

## Usage

#### 1. AuthProvider

`AuthProvider` relies on the [context feature of React](https://reactjs.org/docs/context.html) to pass the `Auth` down 
to the components, so you need to make sure that `AuthProvider` is a parent of the `Routing components`.
You can learn more about this in the API section.

```jsx
import {AuthProvider} from "jwt-auth-react";

...

<AuthProvider>
    <RouteComponent />
</AuthProvider>
```

#### 2. PrivateRoute
`PrivateRoute` is based on [react-router-dom](https://reacttraining.com/react-router) same as the 
[`Route` component of React Router](https://reacttraining.com/react-router/web/api/Route). 
It creates a Route to an `Authentication` based component.
If the user is not authenticated, it will redirect to `login` Page.

```jsx
import {BrowserRouter, Route} from "react-router-dom";
import {PrivateRoute} from "jwt-auth-react";

...

<BrowserRouter>
    <Route component={LoginComponent} path={LOGIN_URL} exact/>
    ...
    <PrivateRoute component={DashboardComponent} path={DASHBOARD_URL} loginPath={LOGIN_URL}/>
</BrowserRouter>
```